History
=======

0.0.1 (2021-05-21)
------------------

* Added REST Interface for:
    * subscription
    * unsubscription
    * microservice health status update
    * periodic service for microservice health status check
* Redis integration

0.0.2 (2021-06-14)
------------------

* added cli support

0.0.3 (2021-07-27)
------------------

* Add a graceful stop timeout to `DiscoveryService`.
* Add `__main__.py`.
* Fix bugs related with connection.
